[Scummvm-cvs-logs] SF.net SVN: scummvm: [29145] scummvm/trunk/engines/saga

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Sun Sep 30 15:19:31 CEST 2007


Revision: 29145
          http://scummvm.svn.sourceforge.net/scummvm/?rev=29145&view=rev
Author:   thebluegr
Date:     2007-09-30 06:19:31 -0700 (Sun, 30 Sep 2007)

Log Message:
-----------
IHNM does not have excuse texts

Modified Paths:
--------------
    scummvm/trunk/engines/saga/interface.cpp
    scummvm/trunk/engines/saga/script.cpp

Modified: scummvm/trunk/engines/saga/interface.cpp
===================================================================
--- scummvm/trunk/engines/saga/interface.cpp	2007-09-30 12:35:37 UTC (rev 29144)
+++ scummvm/trunk/engines/saga/interface.cpp	2007-09-30 13:19:31 UTC (rev 29145)
@@ -874,7 +874,7 @@
 		textFont = kKnownFontMedium;
 		textShadowKnownColor = kKnownColorVerbTextShadow;
 	} else {
-		if (panelButton->id < 39 || panelButton->id > 50) {
+		if (panelButton->id < 39) {
 			// Read non-hardcoded strings from the LUT string table, loaded from the game
 			// data files
 			text = _vm->_script->_mainStrings.getString(IHNMTextStringIdsLUT[panelButton->id]);
@@ -2223,7 +2223,7 @@
 		textWidth = _vm->_font->getStringWidth(kKnownFontMedium, text, 0, kFontNormal);
 		textHeight = _vm->_font->getHeight(kKnownFontMedium);
 	} else {
-		if (textId < 39 || textId > 50) {
+		if (textId < 39) {
 			// Read non-hardcoded strings from the LUT string table, loaded from the game
 			// data files
 			text = _vm->_script->_mainStrings.getString(IHNMTextStringIdsLUT[textId]);

Modified: scummvm/trunk/engines/saga/script.cpp
===================================================================
--- scummvm/trunk/engines/saga/script.cpp	2007-09-30 12:35:37 UTC (rev 29144)
+++ scummvm/trunk/engines/saga/script.cpp	2007-09-30 13:19:31 UTC (rev 29145)
@@ -516,13 +516,16 @@
 		_vm->_events->queue(&event);
 
 	} else {
-		_vm->getExcuseInfo(_pendingVerb, excuseText, excuseSampleResourceId);
-		if (excuseText) {
-			// In Floppy versions we don't have excuse texts
-			if (!(_vm->getFeatures() & GF_CD_FX))
-				excuseSampleResourceId = -1;
+		// Show excuse text in ITE CD Versions
+		if (_vm->getGameType() == GType_ITE) {
+			_vm->getExcuseInfo(_pendingVerb, excuseText, excuseSampleResourceId);
+			if (excuseText) {
+				// In Floppy versions we don't have excuse texts
+				if (!(_vm->getFeatures() & GF_CD_FX))
+					excuseSampleResourceId = -1;
 
-			_vm->_actor->actorSpeech(ID_PROTAG, &excuseText, 1, excuseSampleResourceId, 0);
+				_vm->_actor->actorSpeech(ID_PROTAG, &excuseText, 1, excuseSampleResourceId, 0);
+			}
 		}
 	}
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list